@@ -47,7 +47,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
      Phi <- NULL
       if(rotate != "none") {if (nfactors > 1) {
   
-   	if (rotate=="varimax" | rotate=="quartimax") { 
+   	if (rotate=="varimax" | rotate== "Varimax" |rotate=="quartimax") { 
    			rotated <- do.call(rotate,list(loadings))
    			loadings <- rotated$loadings
    			 colnames(loadings) <- paste("RC",1:nfactors,sep='')
@@ -55,7 +55,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
      			if ((rotate=="promax")|(rotate=="Promax")) {pro <- Promax(loadings)
      			                loadings <- pro$loadings
      			                Phi <- pro$Phi} else {
-     			if (rotate == "cluster") {loadings <- varimax(loadings)$loadings           			
+     			if (rotate == "cluster") {loadings <- Varimax(loadings)$loadings           			
 								pro <- target.rot(loadings)
      			              	loadings <- pro$loadings
      			              	colnames(loadings) <- paste("TC",1:nfactors,sep='')
